@@ -61,8 +61,8 @@ sub spawn {
             _but_attack_done               => \&_ongui_but_attack_done,
             _but_attack_redo               => \&_ongui_but_attack_redo,
             _but_move_armies_done          => \&_ongui_but_move_armies_done,
-            _but_place_armies_done               => \&_ongui_but_place_armies_done,
-            _but_place_armies_redo               => \&_ongui_but_place_armies_redo,
+            _but_place_armies_done         => \&_ongui_but_place_armies_done,
+            _but_place_armies_redo         => \&_ongui_but_place_armies_redo,
             _canvas_attack_cancel          => \&_ongui_canvas_attack_cancel,
             _canvas_attack_from            => \&_ongui_canvas_attack_from,
             _canvas_attack_target          => \&_ongui_canvas_attack_target,
@@ -72,22 +72,22 @@ sub spawn {
             _canvas_move_armies_target     => \&_ongui_canvas_move_armies_target,
             _canvas_place_armies           => \&_ongui_canvas_place_armies,
             _canvas_place_armies_initial   => \&_ongui_canvas_place_armies_initial,
-            _canvas_motion       => \&_ongui_canvas_motion,
+            _canvas_motion                 => \&_ongui_canvas_motion,
             # public events
-            attack                     => \&_onpub_attack,
-            attack_info                => \&_onpub_attack_info,
-            chnum                      => \&_onpub_country_redraw,
-            chown                      => \&_onpub_country_redraw,
-            game_over                     => \&_onpub_game_over,
-            load_map             => \&_onpub_load_map,
-            move_armies                   => \&_onpub_move_armies,
-            move_armies_move              => \&_onpub_move_armies_move,
-            place_armies               => \&_onpub_place_armies,
-            place_armies_initial       => \&_onpub_place_armies_initial,
-            place_armies_initial_count => \&_onpub_place_armies_initial_count,
-            player_active        => \&_onpub_player_active,
-            player_add           => \&_onpub_player_add,
-            player_lost          => \&_onpub_player_lost,
+            attack                         => \&_onpub_attack,
+            attack_info                    => \&_onpub_attack_info,
+            chnum                          => \&_onpub_country_redraw,
+            chown                          => \&_onpub_country_redraw,
+            game_over                      => \&_onpub_game_over,
+            load_map                       => \&_onpub_load_map,
+            move_armies                    => \&_onpub_move_armies,
+            move_armies_move               => \&_onpub_move_armies_move,
+            place_armies                   => \&_onpub_place_armies,
+            place_armies_initial           => \&_onpub_place_armies_initial,
+            place_armies_initial_count     => \&_onpub_place_armies_initial_count,
+            player_active                  => \&_onpub_player_active,
+            player_add                     => \&_onpub_player_add,
+            player_lost                    => \&_onpub_player_lost,
         },
     );
     return $session->ID;
@@ -1045,7 +1045,7 @@ sub _ongui_canvas_move_armies_target {
     # request user how many armies to move
     my $src = $h->{src};
     my $max = $src->armies - 1 - ($h->{fake_armies_out}{ $src->id }//0);
-    K->post('move-armies', 'move_armies', $h->{src}, $country, $max);
+    K->post('move-armies', 'ask_move_armies', $h->{src}, $country, $max);
 }
 
 
