@@ -13,6 +13,8 @@ use 5.010;
 use strict;
 use warnings;
 
+use List::MoreUtils qw{ all };
+
 use base qw{ Class::Accessor::Fast };
 __PACKAGE__->mk_accessors( qw{ id bonus name _countries } );
 
@@ -46,6 +48,18 @@ sub countries {
 }
 
 
+#
+# my $p0wned = $continent->is_owned( $player );
+#
+# Return true if $player is the owner of all $continent's countries.
+#
+sub is_owned {
+    my ($self, $player) = @_;
+
+    return all { $_->owner eq $player } $self->countries;
+}
+
+
 1;
 
 __END__
@@ -127,6 +141,11 @@ located within the C<$continent>.
 Return the list of countries located in C<$continent>.
 
 
+=item * my $p0wned = $continent->is_owned( $player )
+
+Return true if C<$player> is the owner of all C<$continent>'s countries.
+
+
 =back
 
 
